pub enum TokenFlags {
WordBoundary,
SentenceEnd,
}Expand description
Flags for what type of token is being returned.
Variants
WordBoundary
If set, this token marks the start of a new word.
SentenceEnd
If set, this token marks the end of a sentence, meaning the token is equal to “.”, “!”, or “?”. Some models may not have this token.